# Code generated by stigmer-codegen. DO NOT EDIT.

from __future__ import annotations

from dataclasses import dataclass, field
from typing import Any

import grpc

from ai.stigmer.agentic.workflow.v1 import api_pb2
from ai.stigmer.agentic.workflow.v1 import command_pb2_grpc
from ai.stigmer.agentic.workflow.v1 import query_pb2_grpc
from ai.stigmer.agentic.workflow.v1 import io_pb2
from ai.stigmer.agentic.workflow.v1 import spec_pb2
from ai.stigmer.commons.apiresource import io_pb2 as apiresource_io_pb2
from ai.stigmer.commons.apiresource import metadata_pb2
from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_kind_pb2

from ._errors import wrap_error
from ._types import EnvSpecInput, ResourceRef


class WorkflowClient:
    """Provides operations on workflow resources."""

    def __init__(self, channel: grpc.Channel) -> None:
        self._command = command_pb2_grpc.WorkflowCommandControllerStub(channel)
        self._query = query_pb2_grpc.WorkflowQueryControllerStub(channel)

    def apply(self, input: WorkflowInput) -> api_pb2.Workflow:
        try:
            return self._command.apply(input._to_proto())
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def create(self, input: WorkflowInput) -> api_pb2.Workflow:
        try:
            return self._command.create(input._to_proto())
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def update(self, input: WorkflowInput) -> api_pb2.Workflow:
        try:
            return self._command.update(input._to_proto())
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def delete(self, id: str) -> api_pb2.Workflow:
        try:
            return self._command.delete(io_pb2.WorkflowId(value=id))
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def get(self, id: str) -> api_pb2.Workflow:
        try:
            return self._query.get(io_pb2.WorkflowId(value=id))
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def get_by_reference(self, ref: ResourceRef) -> api_pb2.Workflow:
        try:
            proto = ref._to_proto()
            proto.kind = api_resource_kind_pb2.workflow
            return self._query.getByReference(proto)
        except grpc.RpcError as e:
            raise wrap_error(e) from e


@dataclass
class WorkflowInput:
    """Input for creating or updating a Workflow."""

    name: str
    org: str
    document: WorkflowDocumentInput | None
    slug: str | None = None
    labels: dict[str, str] | None = None
    description: str = ""
    tasks: list[WorkflowTaskInput] = field(default_factory=list)
    env_spec: EnvSpecInput | None = None

    def _to_proto(self) -> api_pb2.Workflow:
        spec = spec_pb2.WorkflowSpec(
            description=self.description,
        )
        if self.document is not None:
            spec.document.CopyFrom(self.document._to_proto())
        for item in self.tasks:
            spec.tasks.append(item._to_proto())
        if self.env_spec is not None:
            spec.env_spec.CopyFrom(self.env_spec._to_proto())
        metadata = metadata_pb2.ApiResourceMetadata(
            name=self.name,
            org=self.org,
        )
        if self.slug:
            metadata.slug = self.slug
        if self.labels:
            metadata.labels.update(self.labels)
        return api_pb2.Workflow(
            api_version="agentic.stigmer.ai/v1",
            kind="Workflow",
            metadata=metadata,
            spec=spec,
        )


@dataclass
class WorkflowDocumentInput:
    """SDK input type for WorkflowDocument."""

    namespace: str
    name: str
    version: str
    dsl: str = ""
    description: str = ""

    def _to_proto(self) -> spec_pb2.WorkflowDocument:
        msg = spec_pb2.WorkflowDocument(
            dsl=self.dsl,
            namespace=self.namespace,
            name=self.name,
            version=self.version,
            description=self.description,
        )
        return msg


@dataclass
class WorkflowTaskInput:
    """SDK input type for WorkflowTask."""

    name: str
    kind: int
    task_config: dict[str, Any]
    export: ExportInput | None = None
    flow: FlowControlInput | None = None

    def _to_proto(self) -> spec_pb2.WorkflowTask:
        msg = spec_pb2.WorkflowTask(
            name=self.name,
            kind=self.kind,
        )
        if self.task_config:
            msg.task_config.update(self.task_config)
        if self.export is not None:
            msg.export.CopyFrom(self.export._to_proto())
        if self.flow is not None:
            msg.flow.CopyFrom(self.flow._to_proto())
        return msg


@dataclass
class ExportInput:
    """SDK input type for Export."""

    as_: str = ""

    def _to_proto(self) -> spec_pb2.Export:
        msg = spec_pb2.Export()
        setattr(msg, "as", self.as_)
        return msg


@dataclass
class FlowControlInput:
    """SDK input type for FlowControl."""

    then: str = ""

    def _to_proto(self) -> spec_pb2.FlowControl:
        msg = spec_pb2.FlowControl(
            then=self.then,
        )
        return msg




# Code generated by stigmer-codegen. DO NOT EDIT.

from __future__ import annotations

from dataclasses import dataclass, field

import grpc

from ai.stigmer.agentic.executioncontext.v1 import api_pb2
from ai.stigmer.agentic.executioncontext.v1 import command_pb2_grpc
from ai.stigmer.agentic.executioncontext.v1 import query_pb2_grpc
from ai.stigmer.agentic.executioncontext.v1 import io_pb2
from ai.stigmer.agentic.executioncontext.v1 import spec_pb2
from ai.stigmer.commons.apiresource import io_pb2 as apiresource_io_pb2
from ai.stigmer.commons.apiresource import metadata_pb2
from ai.stigmer.agentic.executioncontext.v1 import spec_pb2 as executioncontext_spec_pb2
from ai.stigmer.commons.apiresource.apiresourcekind import api_resource_kind_pb2

from ._errors import wrap_error
from ._types import DeleteResourceInput, EnvVarInput, ResourceRef


class ExecutionContextClient:
    """Provides operations on executioncontext resources."""

    def __init__(self, channel: grpc.Channel) -> None:
        self._command = command_pb2_grpc.ExecutionContextCommandControllerStub(channel)
        self._query = query_pb2_grpc.ExecutionContextQueryControllerStub(channel)

    def apply(self, input: ExecutionContextInput) -> api_pb2.ExecutionContext:
        try:
            return self._command.apply(input._to_proto())
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def create(self, input: ExecutionContextInput) -> api_pb2.ExecutionContext:
        try:
            return self._command.create(input._to_proto())
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def delete(self, input: DeleteResourceInput) -> api_pb2.ExecutionContext:
        try:
            return self._command.delete(input._to_proto())
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def get(self, id: str) -> api_pb2.ExecutionContext:
        try:
            return self._query.get(io_pb2.ExecutionContextId(value=id))
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def get_by_reference(self, ref: ResourceRef) -> api_pb2.ExecutionContext:
        try:
            proto = ref._to_proto()
            proto.kind = api_resource_kind_pb2.execution_context
            return self._query.getByReference(proto)
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def get_by_execution_id(self, input: io_pb2.ExecutionContextExecutionIdInput) -> api_pb2.ExecutionContext:
        try:
            return self._query.getByExecutionId(input)
        except grpc.RpcError as e:
            raise wrap_error(e) from e


@dataclass
class ExecutionContextInput:
    """Input for creating or updating a ExecutionContext."""

    name: str
    org: str
    slug: str | None = None
    labels: dict[str, str] | None = None
    execution_id: str = ""
    data: dict[str, EnvVarInput] = field(default_factory=dict)

    def _to_proto(self) -> api_pb2.ExecutionContext:
        spec = spec_pb2.ExecutionContextSpec(
            execution_id=self.execution_id,
        )
        for k, v in self.data.items():
            spec.data[k].CopyFrom(executioncontext_spec_pb2.ExecutionValue(
                value=v.value, is_secret=v.is_secret,
            ))
        metadata = metadata_pb2.ApiResourceMetadata(
            name=self.name,
            org=self.org,
        )
        if self.slug:
            metadata.slug = self.slug
        if self.labels:
            metadata.labels.update(self.labels)
        return api_pb2.ExecutionContext(
            api_version="agentic.stigmer.ai/v1",
            kind="ExecutionContext",
            metadata=metadata,
            spec=spec,
        )




"""Top-level Stigmer API client."""

from __future__ import annotations

from types import TracebackType

import grpc

from ._gen._agent import AgentClient
from ._gen._agentexecution import AgentExecutionClient
from ._gen._agentinstance import AgentInstanceClient
from ._gen._apikey import ApiKeyClient
from ._gen._environment import EnvironmentClient
from ._gen._executioncontext import ExecutionContextClient
from ._gen._iampolicy import IamPolicyClient
from ._gen._identityaccount import IdentityAccountClient
from ._gen._identityprovider import IdentityProviderClient
from ._gen._mcpserver import McpServerClient
from ._gen._organization import OrganizationClient
from ._gen._project import ProjectClient
from ._gen._session import SessionClient
from ._gen._skill import SkillClient
from ._gen._workflow import WorkflowClient
from ._gen._workflowexecution import WorkflowExecutionClient
from ._gen._workflowinstance import WorkflowInstanceClient
from ._github import GitHubClient
from ._search import SearchClient
from ._transport import DEFAULT_TARGET, create_channel


class StigmerClient:
    """Stigmer API client.

    Creates a gRPC channel to the Stigmer platform and exposes typed
    sub-clients for every resource kind, plus a cross-resource
    :attr:`search` client and a :attr:`github` OAuth client.

    Usage::

        client = StigmerClient("sk_live_abc123")
        agent = client.agents.get("agent-id")
        client.close()

    As a context manager::

        with StigmerClient("sk_live_abc123") as client:
            agent = client.agents.get("agent-id")
    """

    agents: AgentClient
    agent_executions: AgentExecutionClient
    agent_instances: AgentInstanceClient
    api_keys: ApiKeyClient
    environments: EnvironmentClient
    execution_contexts: ExecutionContextClient
    iam_policies: IamPolicyClient
    identity_accounts: IdentityAccountClient
    identity_providers: IdentityProviderClient
    mcp_servers: McpServerClient
    organizations: OrganizationClient
    projects: ProjectClient
    sessions: SessionClient
    skills: SkillClient
    workflows: WorkflowClient
    workflow_executions: WorkflowExecutionClient
    workflow_instances: WorkflowInstanceClient
    search: SearchClient
    github: GitHubClient

    def __init__(
        self,
        api_key: str,
        *,
        base_url: str = DEFAULT_TARGET,
        insecure: bool = False,
    ) -> None:
        if not api_key:
            raise ValueError("stigmer: API key is required")

        self._channel = create_channel(base_url, api_key, insecure=insecure)
        self._init_clients(self._channel)

    def _init_clients(self, channel: grpc.Channel) -> None:
        """Wire up all resource sub-clients from the gRPC channel."""
        from ._gen._client import GeneratedClient

        gen = GeneratedClient(channel)

        self.agents = gen.agents
        self.agent_executions = gen.agent_executions
        self.agent_instances = gen.agent_instances
        self.api_keys = gen.api_keys
        self.environments = gen.environments
        self.execution_contexts = gen.execution_contexts
        self.iam_policies = gen.iam_policies
        self.identity_accounts = gen.identity_accounts
        self.identity_providers = gen.identity_providers
        self.mcp_servers = gen.mcp_servers
        self.organizations = gen.organizations
        self.projects = gen.projects
        self.sessions = gen.sessions
        self.skills = gen.skills
        self.workflows = gen.workflows
        self.workflow_executions = gen.workflow_executions
        self.workflow_instances = gen.workflow_instances

        self.search = SearchClient(channel)
        self.github = GitHubClient(channel)

    def close(self) -> None:
        """Release the underlying gRPC channel."""
        if self._channel is not None:
            self._channel.close()

    def __enter__(self) -> StigmerClient:
        return self

    def __exit__(
        self,
        exc_type: type[BaseException] | None,
        exc_val: BaseException | None,
        exc_tb: TracebackType | None,
    ) -> None:
        self.close()



# Code generated by stigmer-codegen. DO NOT EDIT.

from __future__ import annotations

import enum

import grpc


class ErrorCode(enum.Enum):
    """Error codes mapped from gRPC status codes."""

    UNKNOWN = "unknown"
    NOT_FOUND = "not-found"
    PERMISSION_DENIED = "permission-denied"
    UNAUTHENTICATED = "unauthenticated"
    INVALID_ARGUMENT = "invalid-argument"
    ALREADY_EXISTS = "already-exists"
    RESOURCE_EXHAUSTED = "resource-exhausted"
    FAILED_PRECONDITION = "failed-precondition"
    INTERNAL = "internal"
    UNAVAILABLE = "unavailable"
    CANCELLED = "cancelled"


_GRPC_CODE_MAP: dict[grpc.StatusCode, ErrorCode] = {
    grpc.StatusCode.NOT_FOUND: ErrorCode.NOT_FOUND,
    grpc.StatusCode.PERMISSION_DENIED: ErrorCode.PERMISSION_DENIED,
    grpc.StatusCode.UNAUTHENTICATED: ErrorCode.UNAUTHENTICATED,
    grpc.StatusCode.INVALID_ARGUMENT: ErrorCode.INVALID_ARGUMENT,
    grpc.StatusCode.ALREADY_EXISTS: ErrorCode.ALREADY_EXISTS,
    grpc.StatusCode.RESOURCE_EXHAUSTED: ErrorCode.RESOURCE_EXHAUSTED,
    grpc.StatusCode.FAILED_PRECONDITION: ErrorCode.FAILED_PRECONDITION,
    grpc.StatusCode.INTERNAL: ErrorCode.INTERNAL,
    grpc.StatusCode.UNAVAILABLE: ErrorCode.UNAVAILABLE,
    grpc.StatusCode.CANCELLED: ErrorCode.CANCELLED,
}


class StigmerError(Exception):
    """Structured error type returned by all SDK operations."""

    def __init__(
        self,
        code: ErrorCode,
        message: str,
        grpc_code: grpc.StatusCode,
    ) -> None:
        super().__init__(message)
        self.code = code
        self.grpc_code = grpc_code

    def __repr__(self) -> str:
        return f"StigmerError(code={self.code.value!r}, message={str(self)!r})"


def wrap_error(err: grpc.RpcError) -> StigmerError:
    """Convert a gRPC RpcError into a StigmerError."""
    grpc_code = err.code()
    code = _GRPC_CODE_MAP.get(grpc_code, ErrorCode.UNKNOWN)
    message = err.details() or str(err)
    return StigmerError(code, message, grpc_code)


def is_not_found(err: BaseException) -> bool:
    """Check whether an error represents a NOT_FOUND status."""
    return isinstance(err, StigmerError) and err.code == ErrorCode.NOT_FOUND


def is_unauthenticated(err: BaseException) -> bool:
    """Check whether an error represents an UNAUTHENTICATED status."""
    return isinstance(err, StigmerError) and err.code == ErrorCode.UNAUTHENTICATED


def is_permission_denied(err: BaseException) -> bool:
    """Check whether an error represents a PERMISSION_DENIED status."""
    return isinstance(err, StigmerError) and err.code == ErrorCode.PERMISSION_DENIED


def is_retryable(err: BaseException) -> bool:
    """Check whether the error is transient and the operation can be retried."""
    return isinstance(err, StigmerError) and err.code in (
        ErrorCode.INTERNAL,
        ErrorCode.UNAVAILABLE,
    )



# Code generated by stigmer-codegen. DO NOT EDIT.

from __future__ import annotations

from dataclasses import dataclass

import grpc

from ai.stigmer.iam.iampolicy.v1 import api_pb2
from ai.stigmer.iam.iampolicy.v1 import command_pb2_grpc
from ai.stigmer.iam.iampolicy.v1 import query_pb2_grpc
from ai.stigmer.iam.iampolicy.v1 import io_pb2
from ai.stigmer.iam.iampolicy.v1 import spec_pb2
from ai.stigmer.commons.apiresource import metadata_pb2

from ._errors import wrap_error


class IamPolicyClient:
    """Provides operations on iampolicy resources."""

    def __init__(self, channel: grpc.Channel) -> None:
        self._command = command_pb2_grpc.IamPolicyCommandControllerStub(channel)
        self._query = query_pb2_grpc.IamPolicyQueryControllerStub(channel)

    def create(self, input: io_pb2.IamPolicySpec) -> api_pb2.IamPolicy:
        try:
            return self._command.create(input)
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def delete(self, input: io_pb2.IamPolicySpec) -> api_pb2.IamPolicy:
        try:
            return self._command.delete(input)
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def bootstrap_policy(self, input: io_pb2.IamPolicySpec) -> api_pb2.IamPolicy:
        try:
            return self._command.bootstrapPolicy(input)
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def cleanup_resource_policies(self, input: io_pb2.ApiResourceRef) -> None:
        try:
            self._command.cleanupResourcePolicies(input)
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def get(self, id: str) -> api_pb2.IamPolicy:
        try:
            return self._query.get(io_pb2.IamPolicyId(value=id))
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def check_authorization(self, input: io_pb2.CheckAuthorizationInput) -> io_pb2.CheckAuthorizationResult:
        try:
            return self._query.checkAuthorization(input)
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def list_authorized_resource_ids(self, input: io_pb2.ListAuthorizedResourceIdsInput) -> io_pb2.AuthorizedResourceIdsList:
        try:
            return self._query.listAuthorizedResourceIds(input)
        except grpc.RpcError as e:
            raise wrap_error(e) from e

    def list_authorized_principal_ids(self, input: io_pb2.ListAuthorizedPrincipalIdsInput) -> io_pb2.AuthorizedPrincipalIdsList:
        try:
            return self._query.listAuthorizedPrincipalIds(input)
        except grpc.RpcError as e:
            raise wrap_error(e) from e


@dataclass
class IamPolicyInput:
    """Input for creating or updating a IamPolicy."""

    name: str
    org: str
    principal: ApiResourceRefInput | None
    resource: ApiResourceRefInput | None
    relation: str
    slug: str | None = None
    labels: dict[str, str] | None = None

    def _to_proto(self) -> api_pb2.IamPolicy:
        spec = spec_pb2.IamPolicySpec(
            relation=self.relation,
        )
        if self.principal is not None:
            spec.principal.CopyFrom(self.principal._to_proto())
        if self.resource is not None:
            spec.resource.CopyFrom(self.resource._to_proto())
        metadata = metadata_pb2.ApiResourceMetadata(
            name=self.name,
            org=self.org,
        )
        if self.slug:
            metadata.slug = self.slug
        if self.labels:
            metadata.labels.update(self.labels)
        return api_pb2.IamPolicy(
            api_version="iam.stigmer.ai/v1",
            kind="IamPolicy",
            metadata=metadata,
            spec=spec,
        )


@dataclass
class ApiResourceRefInput:
    """SDK input type for ApiResourceRef."""

    kind: str
    id: str
    relation: str = ""

    def _to_proto(self) -> spec_pb2.ApiResourceRef:
        msg = spec_pb2.ApiResourceRef(
            kind=self.kind,
            id=self.id,
            relation=self.relation,
        )
        return msg




"""Stigmer Python SDK — typed API client for all Stigmer platform resources.

Usage::

    from stigmer import StigmerClient, AgentInput

    with StigmerClient("sk_live_abc123") as client:
        agent = client.agents.create(AgentInput(name="my-agent", org="my-org"))
        print(agent.metadata.name)
"""

from ._client import StigmerClient
from ._github import (
    ExchangeOAuthCodeParams,
    GetOAuthAuthorizeUrlParams,
    GitHubClient,
    OAuthAuthorizeUrlResponse,
    OAuthTokenResponse,
)
from ._search import ApiResourceKind, SearchClient, SearchParams, SearchResponse

# --- Resource clients and input types (generated) --------------------------

from ._gen._agent import (
    AgentClient,
    AgentInput,
    McpAccessInput,
    McpServerUsageInput,
    SubAgentInput,
    ToolApprovalOverrideInput,
)
from ._gen._agentexecution import (
    AgentExecutionClient,
    AgentExecutionInput,
    AttachmentInput,
    ContextManagementConfigInput,
    ExecutionConfigInput,
)
from ._gen._agentinstance import AgentInstanceClient, AgentInstanceInput
from ._gen._apikey import ApiKeyClient, ApiKeyInput
from ._gen._environment import EnvironmentClient, EnvironmentInput
from ._gen._executioncontext import ExecutionContextClient, ExecutionContextInput
from ._gen._iampolicy import ApiResourceRefInput, IamPolicyClient, IamPolicyInput
from ._gen._identityaccount import IdentityAccountClient, IdentityAccountInput
from ._gen._identityprovider import IdentityProviderClient, IdentityProviderInput
from ._gen._mcpserver import (
    HttpServerConfigInput,
    McpServerClient,
    McpServerInput,
    StdioServerConfigInput,
    ToolApprovalPolicyInput,
)
from ._gen._organization import OrganizationClient, OrganizationInput
from ._gen._project import ProjectClient, ProjectInput
from ._gen._session import (
    GitRepoSourceInput,
    LocalPathSourceInput,
    SessionClient,
    SessionInput,
    WorkspaceEntryInput,
    WorkspaceSourceInput,
)
from ._gen._skill import SkillClient, SkillInput
from ._gen._workflow import (
    ExportInput,
    FlowControlInput,
    WorkflowClient,
    WorkflowDocumentInput,
    WorkflowInput,
    WorkflowTaskInput,
)
from ._gen._workflowexecution import WorkflowExecutionClient, WorkflowExecutionInput
from ._gen._workflowinstance import WorkflowInstanceClient, WorkflowInstanceInput

# --- Shared types (generated) ----------------------------------------------

from ._gen._types import (
    DeleteResourceInput,
    EnvSpecInput,
    EnvVarInput,
    ListParams,
    ListResult,
    Page,
    ResourceRef,
)

# --- Error types (generated) -----------------------------------------------

from ._gen._errors import (
    ErrorCode,
    StigmerError,
    is_not_found,
    is_permission_denied,
    is_retryable,
    is_unauthenticated,
)

__all__ = [
    # Client
    "StigmerClient",
    # GitHub
    "ExchangeOAuthCodeParams",
    "GetOAuthAuthorizeUrlParams",
    "GitHubClient",
    "OAuthAuthorizeUrlResponse",
    "OAuthTokenResponse",
    # Search
    "ApiResourceKind",
    "SearchClient",
    "SearchParams",
    "SearchResponse",
    # Resource clients
    "AgentClient",
    "AgentExecutionClient",
    "AgentInstanceClient",
    "ApiKeyClient",
    "EnvironmentClient",
    "ExecutionContextClient",
    "IamPolicyClient",
    "IdentityAccountClient",
    "IdentityProviderClient",
    "McpServerClient",
    "OrganizationClient",
    "ProjectClient",
    "SessionClient",
    "SkillClient",
    "WorkflowClient",
    "WorkflowExecutionClient",
    "WorkflowInstanceClient",
    # Input types
    "AgentInput",
    "AgentExecutionInput",
    "AgentInstanceInput",
    "ApiKeyInput",
    "ApiResourceRefInput",
    "AttachmentInput",
    "ContextManagementConfigInput",
    "DeleteResourceInput",
    "EnvironmentInput",
    "EnvSpecInput",
    "EnvVarInput",
    "ExecutionConfigInput",
    "ExecutionContextInput",
    "ExportInput",
    "FlowControlInput",
    "GitRepoSourceInput",
    "HttpServerConfigInput",
    "IamPolicyInput",
    "IdentityAccountInput",
    "IdentityProviderInput",
    "LocalPathSourceInput",
    "McpAccessInput",
    "McpServerInput",
    "McpServerUsageInput",
    "OrganizationInput",
    "ProjectInput",
    "SessionInput",
    "SkillInput",
    "StdioServerConfigInput",
    "SubAgentInput",
    "ToolApprovalOverrideInput",
    "ToolApprovalPolicyInput",
    "WorkflowDocumentInput",
    "WorkflowExecutionInput",
    "WorkflowInput",
    "WorkflowInstanceInput",
    "WorkflowTaskInput",
    "WorkspaceEntryInput",
    "WorkspaceSourceInput",
    # Shared types
    "ListParams",
    "ListResult",
    "Page",
    "ResourceRef",
    # Errors
    "ErrorCode",
    "StigmerError",
    "is_not_found",
    "is_permission_denied",
    "is_retryable",
    "is_unauthenticated",
]
